@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 '''
-@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
-@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/Nt8E8vC-ZsoN1McTOYbY2g
-@个人网站      ：www.python-office.com
+@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：CoderWanFeng
+@读者群     ：http://www.python4office.cn/wechat-group/
+@学习网站      ：https://www.python-office.com
 @代码日期    ：2023/8/22 23:28
 '''
 
@@ -13,14 +13,14 @@ import popdf
 from office.lib.decorator_utils.instruction_url import instruction
 
 
-@instruction
+# @instruction
 def add_watermark() -> None:
     popdf.add_watermark()
 
 
 # 给pdf加水印-有参数
 # @except_dec()
-@instruction
+# @instruction
 def add_mark(pdf_file, mark_str, output_path=None, output_file_name=None) -> None:
     """
     必填参数：
@@ -34,7 +34,7 @@ def add_mark(pdf_file, mark_str, output_path=None, output_file_name=None) -> Non
 
 # 给pdf加水印-有参数
 # @except_dec()
-@instruction
+# @instruction
 def add_watermark_by_parameters(pdf_file, mark_str, output_path=None, output_file_name=None) -> None:
     """
     给PDF添加水印
@@ -52,35 +52,35 @@ def add_watermark_by_parameters(pdf_file, mark_str, output_path=None, output_fil
 
 # txt转pdf
 # @except_dec()
-@instruction
+# @instruction
 def txt2pdf(path: str, res_pdf='txt2pdf.popdf', output_path=r'./'):
     popdf.txt2pdf(path, res_pdf, output_path)
 
 
 # PDF加密
 # @except_dec()
-@instruction
+# @instruction
 def encrypt4pdf(path, password, output_path=None):
     popdf.encrypt4pdf(path, password, output_path)
 
 
 # PDF解密
 # @except_dec()
-@instruction
+# @instruction
 def decrypt4pdf(path, password, res_pdf='decrypt.popdf'):
     popdf.decrypt4pdf(path, password, res_pdf)
 
 
 # 合并pdf
 # @except_dec()
-@instruction
+# @instruction
 def merge2pdf(one_by_one, output):
     popdf.merge2pdf(one_by_one, output)
 
 
 # todo：输入文件路径
 # @except_dec()
-@instruction
+# @instruction
 def pdf2docx(file_path: str, output_path: str = './'):
     """
     PDF转Word
@@ -96,12 +96,12 @@ def pdf2docx(file_path: str, output_path: str = './'):
 
 
 # @except_dec()
-@instruction
+# @instruction
 def pdf2imgs(pdf_path, out_dir, merge=False):
     popdf.pdf2imgs(pdf_path, out_dir, merge)
 
 
 # @except_dec()
-@instruction
+# @instruction
 def add_img_water(pdf_file_in, pdf_file_mark, pdf_file_out):
     popdf.add_img_water(pdf_file_in, pdf_file_mark, pdf_file_out)
