@@ -1,32 +1,37 @@
 # -*- coding: UTF-8 -*-
 '''
-@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
-@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/Nt8E8vC-ZsoN1McTOYbY2g
-@个人网站      ：www.python-office.com
+@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：CoderWanFeng
+@读者群     ：http://www.python4office.cn/wechat-group/
+@学习网站      ：https://www.python-office.com
 @代码日期    ：2023/8/22 23:28
 '''
 
+"""
+🤖10讲Python微信机器人，小白也能学会
+https://www.bilibili.com/video/BV1S84y1m7xd/
+"""
+
 import PyOfficeRobot
 
 from office.lib.decorator_utils.instruction_url import instruction
 
 
-@instruction
+# @instruction
 def send_message(who: str, message: str):
     PyOfficeRobot.chat.send_message(who, message)
 
 
-@instruction
+# @instruction
 def send_message_by_time(who, message, time):
     PyOfficeRobot.chat.send_message_by_time(who, message, time)
 
 
-@instruction
+# @instruction
 def chat_by_keywords(who, keywords):
     PyOfficeRobot.chat.chat_by_keywords(who, keywords)
 
 
-@instruction
+# @instruction
 def send_file(who, file):
     PyOfficeRobot.file.send_file(who, file)
 
@@ -37,12 +42,12 @@ def group_send():
 
 # 保存指定人的消息
 # BY：盖飞
-@instruction
+# @instruction
 def receive_message(who='文件传输助手', txt='userMessage.txt', output_path='./'):
     PyOfficeRobot.chat.receive_message(who, txt, output_path)
 
 
-@instruction
+# @instruction
 def chat_robot(who='程序员晚枫'):
     """
     智能聊天
